import type { BaseSchemaDSL } from "@lowcode-set-up-platform/dsl";
import {createContext, forwardRef, useEffect, useImperativeHandle, useRef, useState} from "react";
import RenderView, { RenderViewHandleConfig } from "../render-view";
import { ComponentDependency } from "@lowcode-set-up-platform/component-loader";

interface IProps {
  schema?: BaseSchemaDSL;
}
const RenderContext = createContext<IProps>({});

const PageRender = forwardRef((props: IProps, ref) => {

  const { schema = window.__RENDER_PAGE_STATE__ } = props;

  const [components, setComponents] = useState({});

  const { componentsMap = [], componentsTree = [], packagesMap = [] } = schema || {};

  const [isPackageMount, setIsPackageMount] = useState(false);

  const renderViewHandleConfigRef = useRef<RenderViewHandleConfig>();

  useEffect(() => {
    if (!window.PageComponentDependency) {
      window.PageComponentDependency = window.PageComponentDependency = new ComponentDependency(window);
    }
    void (async () => {
      if (packagesMap?.length) {
        await window.PageComponentDependency.parsePackagesMap(packagesMap);
      }
      if (componentsMap?.length) {
        const comps = await window.PageComponentDependency.parseComponentsMap(componentsMap);
        console.log(comps)
        setComponents(comps);
      }
      setIsPackageMount(true);
    })()

  }, [componentsMap, packagesMap]);

  useImperativeHandle(ref, () => {
    return {
      updateCompProps: (id: string, value: Record<any, any>) => {
        console.log(id, value)
      },
      getRenderRef: () => {
        return renderViewHandleConfigRef?.current?.getRenderRef?.();
      }
    }
  })

  if (!componentsMap || !isPackageMount) {
    return <></>
  }

  return (
    <RenderContext.Provider value={{}}>
      <RenderView
        renderKey={componentsTree?.[0].version}
        schema={schema}
        components={components}
        ref={renderViewHandleConfigRef as any}
      />
    </RenderContext.Provider>
  )
})

export default PageRender
