import { forwardRef, useImperativeHandle, useRef } from "react";
import type { BaseSchemaDSL } from "@lowcode-set-up-platform/dsl";
import ReactRenderer from "../render";
import { getAppHelper } from "@lowcode-set-up-platform/render-app-helper";


export interface RenderViewHandleConfig {
  updateCompProps?: (id: string, value: Record<any, any>) => void;
  getRenderRef?: () => any
}

interface RenderViewIProps {
  schema?: BaseSchemaDSL;
  components: Record<string, any>;
  renderKey: string;
}

const DefaultSchema: BaseSchemaDSL = {
  componentsMap: [],
  componentsTree: [],
  flows: [],
  packagesMap: [],
  version: ""
}

const RenderView = forwardRef<RenderViewHandleConfig, RenderViewIProps>((props: RenderViewIProps, ref) => {

  const { schema = DefaultSchema, components = {}} = props;

  const { componentsMap = [], componentsTree = [] } = schema;

  const renderRef = useRef();

  useImperativeHandle(ref, () => {
    return {
      updateCompProps: (id: string, value: Record<any, any>) => {
        console.log(id, value)
      },
      getRenderRef: () => {
        return renderRef.current
      }
    }
  })


  if (!componentsMap) {
    return <></>
  }

  return (
    <>
      <ReactRenderer
        key={props.renderKey || componentsTree?.[0].version}
        schema={componentsTree?.[0]}
        components={components}
        appHelper={getAppHelper()}
        onCompGetCtx={(_schema, _ref) => {
          renderRef.current = _ref
        }}
      ></ReactRenderer>
    </>
  )
})

export default RenderView;