import React, { Component, ReactInstance, ContextType } from 'react';
import { Runner } from "@lowcode-set-up-platform/logicflow-render"
import ReactDOM from 'react-dom';
import {
  adapter,
  pageRendererFactory,
  componentRendererFactory,
  blockRendererFactory,
  addonRendererFactory,
  tempRendererFactory,
  rendererFactory,
  types,
} from '@lowcode-set-up-platform/renderer-core';
import {getLogger} from "@lowcode-set-up-platform/shared";

const logger = getLogger({ level: 'info', bizName: 'renderer:entry' });
logger.log("window.React====== get run time", window.React)
logger.log("window.ReactDOM====== get run time", window.ReactDOM)
logger.log("window.LogicflowRender====== get run time", (window as any).LogicflowRender)

if (!window.React) {
  logger.log("window.React====== set run time")
  window.React = React;
}
if (!(window as any).ReactDOM) {
  (window as any).ReactDOM = ReactDOM;
}
if (!(window as any).LogicflowRender) {
  (window as any).LogicflowRender = {
    runner: Runner as any
  };
}

console.log(window.React, (window as any).ReactDOM, (window as any).LogicflowRender);

adapter.setRuntime({
  FlowRunner: () => {
    return (window as any).LogicflowRender
  },
  Component: window.React.Component,
  PureComponent:  window.React.PureComponent,
  createContext: window.React.createContext,
  createElement: window.React.createElement,
  forwardRef: window.React.forwardRef,
  findDOMNode: (window as any).ReactDOM.findDOMNode,
});

adapter.setRenderers({
  PageRenderer: pageRendererFactory(),
  ComponentRenderer: componentRendererFactory(),
  BlockRenderer: blockRendererFactory(),
  AddonRenderer: addonRendererFactory(),
  TempRenderer: tempRendererFactory(),
  DivRenderer: blockRendererFactory(),
});


function factory(): types.IRenderComponent {
  const Renderer = rendererFactory();
  // @ts-ignore
  return class ReactRenderer extends Renderer implements Component {
    // @ts-ignore
    readonly props: types.IRendererProps;

    context: ContextType<any>;

    setState!: (
      state: types.IRendererState,
      callback?: () => void,
    ) => void;

    forceUpdate!: (callback?: () => void) => void;

    refs!: {
      [key: string]: ReactInstance;
    };

    constructor(props: types.IRendererProps, context: ContextType<any>) {
      super(props, context);
    }

    isValidComponent(obj: any) {
      return obj?.prototype?.isReactComponent || obj?.prototype instanceof Component;
    }
  };
}

export default factory();
