import { defineConfig } from 'vite';
import dts from "vite-plugin-dts";
import path from "path";
import cssInjectedByJsPlugin from "vite-plugin-css-injected-by-js";

export default defineConfig({
  plugins: [
    dts({
      outDir: 'lib', // 将类型文件直接生成到 lib 目录
      include: ['./src/**'], // 指定包含的文件
      entryRoot: path.resolve(__dirname, './src'), // 将 src 目录作为类型文件生成的根路径

    }),
    cssInjectedByJsPlugin(),
  ],
  build: {
    outDir: 'lib',
    lib: {
      entry: ['src/index.tsx'],
      name: 'OpenReactRenderSdk',
      formats: ['es', 'umd'], // 打包输出格式
      fileName: (format, entryName) => `open-react-render-sdk.${format}.js`,
    },
    rollupOptions: {
      // 将 react 和 react-dom 标记为外部依赖
      external: ['react', 'react-dom'],
      output: {
        globals: {
          react: 'React',
          'react-dom': 'ReactDOM',
        },
      },
    }

  },
});
